@@ -1,6 +1,7 @@
-from math import floor
 import re
 
+from math import floor
+
 from django.forms import BaseForm
 from django.forms.forms import BoundField
 from django.forms.widgets import TextInput, CheckboxInput, CheckboxSelectMultiple, RadioSelect
@@ -8,11 +9,12 @@ from django.template import Context
 from django.template.loader import get_template
 from django import template
 from django.conf import settings
-from django.utils.html import format_html_join
+from django.utils.safestring import mark_safe
+from django.utils.html import escape
 
 
 BOOTSTRAP_BASE_URL = getattr(settings, 'BOOTSTRAP_BASE_URL',
-                             'http://twitter.github.com/bootstrap/assets/'
+                             'http://twitter.github.io/bootstrap/assets/'
 )
 
 BOOTSTRAP_JS_BASE_URL = getattr(settings, 'BOOTSTRAP_JS_BASE_URL',
@@ -181,12 +183,15 @@ def split(text, splitter):
 @register.filter
 def html_attrs(attrs):
     """
-    display the attributes given as html attributes :
+    Display the attributes given as html attributes :
     >>> import collections
     >>> html_attrs(collections.OrderedDict([('href',"http://theurl.com/img.png"), ('alt','hi "guy')]))
     u'href="http://theurl.com/img.png" alt="hi &quot;guy" '
     """
-    return format_html_join(u' ', '{0}="{1}"', (item for item in attrs.items())) + " "
+    pairs = []
+    for name, value in attrs.items():
+        pairs.append(u'%s="%s"' % (escape(name), escape(value)))
+    return mark_safe(u' '.join(pairs))
 
 
 @register.simple_tag(takes_context=True)
